@@ -1,6 +1,6 @@
 package EWS::Calendar::Item;
 BEGIN {
-  $EWS::Calendar::Item::VERSION = '1.103610';
+  $EWS::Calendar::Item::VERSION = '1.103620';
 }
 use Moose;
 
@@ -78,7 +78,7 @@ sub has_Location { return length ((shift)->Location) }
 
 has CalendarItemType => (
     is => 'ro',
-    isa => enum([qw/Single Occurrence Eception/]),
+    isa => enum([qw/Single Occurrence Exception/]),
     required => 1,
 );
 
@@ -193,28 +193,3 @@ sub BUILDARGS {
 __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
-
-__END__
-=pod
-
-=head1 NAME
-
-EWS::Calendar::Item
-
-=head1 VERSION
-
-version 1.103610
-
-=head1 AUTHOR
-
-Oliver Gorwits <oliver@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by University of Oxford.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
