@@ -1,6 +1,6 @@
 package EWS::Contacts::ResultSet;
 BEGIN {
-  $EWS::Contacts::ResultSet::VERSION = '1.103610';
+  $EWS::Contacts::ResultSet::VERSION = '1.103620';
 }
 use Moose;
 use MooseX::Iterator;
@@ -48,28 +48,3 @@ sub _build_iterator {
 __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
-
-__END__
-=pod
-
-=head1 NAME
-
-EWS::Contacts::ResultSet
-
-=head1 VERSION
-
-version 1.103610
-
-=head1 AUTHOR
-
-Oliver Gorwits <oliver@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by University of Oxford.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
